import React, { useState, useEffect, useMemo } from 'react';
import { Card, Tabs, Button, Popconfirm, notification, Spin } from 'antd';
import ProCard from '@ant-design/pro-card';
import PageContainer from '@/components/BasePageContainer';
import {
  miniAppSiteTree,
  getMiniAppModuleTree,
  deleteWebsite,
} from '@/services/mobileConfig/api';
import SiteConfig from './SiteConfig';
import MenuConfig from './menuconfig/MenuConfig';
const { TabPane } = Tabs;
const MobileConfigPage = props => {
  const [activeKey, setActiveKey] = useState('0'); // tabs活动页
  const [miniTitle, setMiniTitle] = useState('');
  const [flag, setFlag] = useState(1);
  const [showConfig, setShowConfig] = useState(true);
  const [loading, setLoading] = useState(false);
  const [position, setPosition] = useState([]);
  const [subType, setSubType] = useState('');
  useEffect(() => {
    // miniAppSiteTree({
    //   userMode: 'admin',
    //   select: '',
    //   _version: 9999,
    //   _dc: new Date().getTime(),
    //   node: -2,
    // })
    setLoading(true);
    getMiniAppModuleTree({
      userMode: 'admin',
    }).then(res => {
      setLoading(false);
      console.log(res, 'res');
      if (res.code === 0) {
        const { data } = res;
        if (data[0].children.length > 0) {
          const title = data[0].children[0].text || '熊猫掌天下小程序';
          setShowConfig(true);
          setMiniTitle(title);
          setPosition(['right']);
        } else {
          setPosition(['left']);
          setShowConfig(false);
        }
      } else {
        setShowConfig(false);
      }
      console.log(res);
    });
  }, [flag]);

  useEffect(() => {
    // getMiniAppModuleTree({
    //   userMode: 'super',
    // }).then(res => {
    //   console.log(res);
    // });
  }, []);
  // 修改选中的tab
  const handleChange = key => {
    setActiveKey(key);
  };
  const submitCallback = () => {
    setFlag(flag + 1);
    setSubType('');
  };
  // 删除小程序
  const delMini = () => {
    deleteWebsite({
      client: 'miniapp',
      _version: 9999,
      _dc: Date.now(),
    }).then(res => {
      if (res.success) {
        setFlag(flag + 1);
        notification.success({
          message: '提示',
          duration: 3,
          description: '删除成功',
        });
      } else {
        notification.success({
          message: '提示',
          duration: 3,
          description: res.message || '删除失败',
        });
      }
    });
  };
  const addMini = () => {
    setShowConfig(true);
    setSubType('add');
  };

  const options = {
    left: (
      <Button type="primary" onClick={addMini}>
        新增小程序
      </Button>
    ),
    right: (
      <Popconfirm
        title="是否删除小程序网站,及相关联的角色和菜单"
        okText="确认"
        cancelText="取消"
        placement="left"
        onConfirm={delMini}
      >
        <Button type="primary" danger>
          删除小程序
        </Button>
      </Popconfirm>
    ),
  };
  const slot = useMemo(() => {
    if (position.length === 0) return null;

    return position.reduce((acc, direction) => {
      console.log(acc, direction);
      return { ...acc, [direction]: options[direction] };
    }, {});
  }, [position]);
  const tabArr = [
    {
      title: '网站配置',
      key: '0',
      component: (
        <SiteConfig
          miniTitle={miniTitle}
          submitCallback={submitCallback}
          subType={subType}
        />
      ),
    },
    {
      title: '菜单管理',
      key: '1',
      component: <MenuConfig />,
    },
  ];
  return (
    <PageContainer>
      <ProCard>
        <Spin tip="loading..." spinning={loading}>
          <Tabs
            activeKey={activeKey}
            type="card"
            onChange={handleChange}
            tabBarExtraContent={slot}
          >
            {showConfig &&
              tabArr?.length > 0 &&
              tabArr.map(item => (
                <TabPane tab={item.title} key={item.key}>
                  {activeKey === item.key && item.component}
                </TabPane>
              ))}
          </Tabs>
        </Spin>
      </ProCard>
    </PageContainer>
  );
};

export default MobileConfigPage;
