import qs from 'qs';
import { CITY_SERVICE, get, PUBLISH_SERVICE, post, postForm } from '../index';

/**
 * 获取所有网站配置
 * @param {*} userMode
 */
export const getWebModuleTree = userMode =>
  get(
    `${PUBLISH_SERVICE}/PlatformCenter/WebModuleTree?${qs.stringify({
      userMode,
    })}`,
  );

/**
 *  获取主题下拉选项
 */
export const getWebThemes = () =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetThemes`, { query: '' });

/**
 * 获取登录模板下拉选项
 */
export const getLoginPage = () =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetLoginPage`, { query: '' });

/**
 * 获取地图配置下拉选项
 */
export const getMapCofigs = () =>
  get(
    `${CITY_SERVICE}/OMS.svc/GetAllConfigText?terminalType=scheme&isBaseMap=false`,
    { query: '' },
  );

/**
 *  获取网站配置
 * @param {*} title 网站标题
 */
export const getWebconfig = title =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetWebsite`, { title });

/**
 * 编辑或添加网站。默认编辑模式
 * @param {*} config 网站配置
 * @param {*} isAdd true：添加  false：编辑
 */
export const postEditWebConfig = (config, isAdd = false) => {
  const obj = { ...config };
  Object.keys(obj).forEach(k => {
    if (typeof obj[k] === 'string') {
      obj[k] = obj[k].trim();
    }
  });
  post(
    `${CITY_SERVICE}/OMS.svc/${
      isAdd ? 'W4_AddWebsite' : 'W4_EditWebsite'
    }?_version=9999`,
    qs.stringify({ config: JSON.stringify(obj) }),
    {
      headers: {
        'content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
      },
    },
  );
};

export const postAddWebSite = config => postEditWebConfig(config, true);

export const deleteWebsite = client =>
  get(`${CITY_SERVICE}/OMS.svc/W4_DeleteWebsite?_version=9999`, { client });
